@@ -7,7 +7,7 @@ assert_has_all_attributes <- function(x, attrs)
     get_name_in_parent(x), 
     toString(sQuote(attrs))
   )
-  assert_engine(x, has_attributes, msg, attrs = attrs)
+  assert_engine(has_attributes, x, attrs = attrs, msg = msg)
 }
 
 #' @rdname has_attributes
@@ -19,7 +19,7 @@ assert_has_any_attributes <- function(x, attrs)
     get_name_in_parent(x), 
     toString(sQuote(attrs))
     )
-  assert_engine(x, has_attributes, msg, what = "any", attrs = attrs)
+  assert_engine(has_attributes, x, attrs = attrs, msg = msg, what = "any")
 }
 
 #' @rdname has_names
@@ -27,7 +27,7 @@ assert_has_any_attributes <- function(x, attrs)
 assert_has_colnames <- function(x)
 {                                       
   msg <- gettextf("%s has no column names.", get_name_in_parent(x))
-  assert_engine(x, has_colnames, msg)
+  assert_engine(has_colnames, x, msg = msg)
 }
 
 #' @rdname has_cols
@@ -35,7 +35,7 @@ assert_has_colnames <- function(x)
 assert_has_cols <- function(x)
 {                                       
   msg <- gettextf("%s has no columns.", get_name_in_parent(x))
-  assert_engine(x, has_cols, msg)
+  assert_engine(has_cols, x, msg = msg)
 }
 
 #' @rdname has_names
@@ -43,7 +43,7 @@ assert_has_cols <- function(x)
 assert_has_dimnames <- function(x)
 {                                       
   msg <- gettextf("%s has no dimension names.", get_name_in_parent(x))
-  assert_engine(x, has_dimnames, msg)
+  assert_engine(has_dimnames, x, msg = msg)
 }
 
 #' @rdname has_dims
@@ -51,7 +51,7 @@ assert_has_dimnames <- function(x)
 assert_has_dims <- function(x)
 {                                                                
   msg <- gettextf("%s has no dimensions attribute.", get_name_in_parent(x))
-  assert_engine(x, has_dims, msg)
+  assert_engine(has_dims, x, msg = msg)
 }
 
 #' @rdname has_duplicates
@@ -59,7 +59,7 @@ assert_has_dims <- function(x)
 assert_has_duplicates <- function(x)
 {                                                                
   msg <- gettextf("%s has no duplicates.", get_name_in_parent(x))
-  assert_engine(x, has_no_duplicates, msg)
+  assert_engine(has_no_duplicates, x, msg = msg)
 }
 
 #' @rdname has_duplicates
@@ -67,7 +67,7 @@ assert_has_duplicates <- function(x)
 assert_has_no_duplicates <- function(x)
 {                                                                
   msg <- gettextf("%s has duplicates.", get_name_in_parent(x))
-  assert_engine(x, has_no_duplicates, msg)
+  assert_engine(has_no_duplicates, x, msg = msg)
 }
 
 #' @rdname has_names
@@ -75,7 +75,7 @@ assert_has_no_duplicates <- function(x)
 assert_has_names <- function(x)
 {                                                             
   msg <- gettextf("%s has no names.", get_name_in_parent(x))
-  assert_engine(x, has_names, msg)
+  assert_engine(has_names, x, msg = msg)
 }
 
 #' @rdname has_names
@@ -83,7 +83,7 @@ assert_has_names <- function(x)
 assert_has_rownames <- function(x)
 {                                                             
   msg <- gettextf("%s has no row names.", get_name_in_parent(x))
-  assert_engine(x, has_rownames, msg)
+  assert_engine(has_rownames, x, msg = msg)
 }
 
 #' @rdname has_cols
@@ -91,7 +91,7 @@ assert_has_rownames <- function(x)
 assert_has_rows <- function(x)
 {                                                             
   msg <- gettextf("%s has no rows.", get_name_in_parent(x))
-  assert_engine(x, has_rows, msg)
+  assert_engine(has_rows, x, msg = msg)
 }
 
 #' @rdname has_terms
@@ -99,5 +99,5 @@ assert_has_rows <- function(x)
 assert_has_terms <- function(x)
 {                                                             
   msg <- gettextf("%s has no terms.", get_name_in_parent(x))
-  assert_engine(x, has_terms, msg)
+  assert_engine(has_terms, x, msg = msg)
 }
