@@ -6,7 +6,7 @@ assert_all_are_dirs <- function(x)
     "The paths %s are not all directories.", 
     get_name_in_parent(x)
   )
-  assert_engine(x, is_dir, msg = msg)
+  assert_engine(is_dir, x, msg = msg)
 }
 
 #' @rdname is_dir
@@ -17,7 +17,7 @@ assert_any_are_dirs <- function(x)
     "The paths %s are all not directories.", 
     get_name_in_parent(x)
   )
-  assert_engine(x, is_dir, msg = msg, what = "any")
+  assert_engine(is_dir, x, msg = msg, what = "any")
 }
 
 #' @rdname is_empty_file
@@ -28,7 +28,7 @@ assert_all_are_empty_files <- function(x)
     "The files %s are not all empty", 
     get_name_in_parent(x)
   )
-  assert_engine(x, is_empty_file, msg = msg)
+  assert_engine(is_empty_file, x, msg = msg)
 }
 
 #' @rdname is_empty_file
@@ -39,7 +39,7 @@ assert_any_are_empty_files <- function(x)
     "The files %s are all not empty.", 
     get_name_in_parent(x)
   )
-  assert_engine(x, is_empty_file, msg = msg, what = "any")
+  assert_engine(is_empty_file, x, msg = msg, what = "any")
 }
 
 #' @rdname is_existing_file
@@ -50,7 +50,7 @@ assert_all_are_existing_files <- function(x)
     "The files %s do not all exist.", 
     get_name_in_parent(x)
   )
-  assert_engine(x, is_existing_file, msg = msg)
+  assert_engine(is_existing_file, x, msg = msg)
 }
 
 #' @rdname is_existing_file
@@ -61,7 +61,7 @@ assert_any_are_existing_files <- function(x)
     "The files %s all do not exist.", 
     get_name_in_parent(x)
     )
-  assert_engine(x, is_existing_file, msg = msg, what = "any")
+  assert_engine(is_existing_file, x, msg = msg, what = "any")
 }
 
 #' @rdname is_executable_file
@@ -72,7 +72,7 @@ assert_all_are_executable_files <- function(x)
     "The files %s are not all executable.", 
     get_name_in_parent(x)
     )
-  assert_engine(x, is_executable_file, msg = msg)
+  assert_engine(is_executable_file, x, msg = msg)
 }
 
 #' @rdname is_executable_file
@@ -83,7 +83,7 @@ assert_any_are_executable_files <- function(x)
     "The files %s all are not executable.", 
     get_name_in_parent(x)
     )
-  assert_engine(x, is_executable_file, msg = msg, what = "any")
+  assert_engine(is_executable_file, x, msg = msg, what = "any")
 }
 
 #' @rdname is_library
@@ -94,7 +94,7 @@ assert_all_are_libraries <- function(x)
     "The paths %s are not all libraries.", 
     get_name_in_parent(x)
   )
-  assert_engine(x, is_library, msg = msg)
+  assert_engine(is_library, x, msg = msg)
 }
 
 #' @rdname is_library
@@ -105,7 +105,7 @@ assert_any_are_libraries <- function(x)
     "The paths %s are all not libraries.", 
     get_name_in_parent(x)
   )
-  assert_engine(x, is_library, msg = msg, what = "any")
+  assert_engine(is_library, x, msg = msg, what = "any")
 }
 #' @rdname is_executable_file
 #' @export
@@ -115,7 +115,7 @@ assert_all_are_readable_files <- function(x)
     "The files %s are not all readable.", 
     get_name_in_parent(x)
     )
-  assert_engine(x, is_readable_file, msg = msg)
+  assert_engine(is_readable_file, x, msg = msg)
 }
 
 #' @rdname is_executable_file
@@ -126,7 +126,7 @@ assert_any_are_readable_files <- function(x)
     "The files %s all are not readable.", 
     get_name_in_parent(x)
     )
-  assert_engine(x, is_readable_file, msg = msg, what = "any")
+  assert_engine(is_readable_file, x, msg = msg, what = "any")
 }
 
 #' @rdname is_executable_file
@@ -137,7 +137,7 @@ assert_all_are_writable_files <- function(x)
     "The files %s are not all writable.", 
     get_name_in_parent(x)
     )
-  assert_engine(x, is_writable_file, msg = msg)
+  assert_engine(is_writable_file, x, msg = msg)
 }
 
 #' @rdname is_executable_file
@@ -148,5 +148,5 @@ assert_any_are_writable_files <- function(x)
     "The files %s all are not writable.", 
     get_name_in_parent(x)
     )
-  assert_engine(x, is_writable_file, msg = msg, what = "any")
+  assert_engine(is_writable_file, x, msg = msg, what = "any")
 }
