@@ -5,7 +5,7 @@ is_imaginary <- function(x, tol = 100 * .Machine$double.eps)
   call_and_name(
     function(x)
     {
-      ok <- ok <- abs(Re(x)) < tol
+      ok <- abs(Re(x)) < tol
       set_cause(ok, "real")
     },
     x
@@ -19,6 +19,10 @@ is_imaginary <- function(x, tol = 100 * .Machine$double.eps)
 #' @param x Input to check.
 #' @param tol Imaginary/real components smaller than \code{tol} are not 
 #' considered.
+#' @param na_ignore A logical value.  If \code{FALSE}, \code{NA} values
+#' cause an error; otherwise they do not.  Like \code{na.rm} in many
+#' stats package functions, except that the position of the failing
+#' values does not change.
 #' @return \code{TRUE} if the input has imaginary component equal to zero.
 #' The \code{assert_*} functions return nothing but
 #' throw an error if the corresponding \code{is_*} function returns 
@@ -35,6 +39,11 @@ is_imaginary <- function(x, tol = 100 * .Machine$double.eps)
 #' is_real(x, 0)
 #' is_imaginary(x)
 #' is_imaginary(x, 0)
+#' # numbers with both a real and imaginary component return FALSE
+#' # (since they are neither purely real nor purely imaginary)
+#' cmplx <- 1 + 1i
+#' is_real(cmplx)
+#' is_imaginary(cmplx)
 #' assert_all_are_real(1:10)
 #' assert_all_are_real(1:10 + 0i)
 #' assert_any_are_real(c(1i, 0))
